@@ -7,10 +7,10 @@
 
 // clang-format off
 #define GKO_VERSION_MAJOR 1
-#define GKO_VERSION_MINOR 9
+#define GKO_VERSION_MINOR 10
 #define GKO_VERSION_PATCH 0
 #define GKO_VERSION_TAG "main"
-#define GKO_VERSION_STR 1, 9, 0
+#define GKO_VERSION_STR 1, 10, 0
 // clang-format on
 
 
@@ -37,6 +37,10 @@
 #define GKO_HAVE_CXXABI_H
 
 
+/* Is std::size_t the same type as std::uint64_t? */
+#define GKO_SIZE_T_IS_UINT64_T
+
+
 /* Should we use all optimizations for Jacobi? */
 /* #undef GINKGO_JACOBI_FULL_OPTIMIZATIONS */
 
@@ -121,10 +125,15 @@
 #define GINKGO_ENABLE_HALF 1
 // clang-format on
 
+/* Is bfloat16 operation available ? */
+// clang-format off
+#define GINKGO_ENABLE_BFLOAT16 1
+// clang-format on
+
 
 /* Do we need to use blocking communication in our SpMV? */
 // clang-format off
-/* #undef GINKGO_FORCE_SPMV_BLOCKING_COMM */
+#define GINKGO_HAVE_OPENMPI_PRE_4_1_X 0
 // clang-format on
 
 
